@@ -11,9 +11,8 @@ from .base import BaseCommand
 class DockerPrepareCommand(BaseCommand):
     """Make docker container nice.
     """
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser('command')
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_docker(parser)
         builders.build_output(parser)
