@@ -14,6 +14,8 @@ from .base import BaseCommand
 class GenerateContributingCommand(BaseCommand):
     """Create CONTRIBUTING.md for DepHell-based project.
     """
+    # because we don't actually use anything from the config
+    find_config = False
     file_name = 'CONTRIBUTING.md'
 
     @staticmethod
@@ -37,6 +39,6 @@ class GenerateContributingCommand(BaseCommand):
         config = dict(config['tool']['dephell'])
         project_path = Path(self.config['project'])
         text = make_contributing(config=config, project_path=project_path)
-        (project_path / self.file_name).write_text(text)
+        (project_path / self.file_name).write_text(text, encoding='utf8')
         self.logger.info('generated', extra=dict(file=self.file_name))
         return True
