@@ -47,6 +47,9 @@ class InspectGadgetCommand(BaseCommand):
 
     This command shouldn't be documented.
     """
+    # because we don't actually use anything from the config
+    find_config = False
+
     @staticmethod
     def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
