@@ -15,9 +15,8 @@ from .base import BaseCommand
 class InspectSelfCommand(BaseCommand):
     """Show information about DepHell installation.
     """
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
