@@ -12,6 +12,8 @@ from .base import BaseCommand
 class JailListCommand(BaseCommand):
     """Show all jails and their entrypoints.
     """
+    find_config = False
+
     @staticmethod
     def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
@@ -23,10 +25,12 @@ class JailListCommand(BaseCommand):
     def __call__(self) -> bool:
         venvs_path = self.config['venv'].replace('-{digest}', '')
         venvs_path = venvs_path.format(project='*', digest='', env='')
-        venvs_path = str(Path(venvs_path))
+        venvs_path = str(Path(venvs_path).resolve())
 
         entrypoints = defaultdict(list)
         for entrypoint in Path(self.config['bin']).iterdir():
+            if not entrypoint.exists():
+                continue  # jail disappeared on disk
             venv_path = entrypoint.resolve().parent.parent
             if venv_path.match(venvs_path):
                 entrypoints[venv_path.name].append(entrypoint.name)
