@@ -13,10 +13,8 @@ from .base import BaseCommand
 class PackageDownloadsCommand(BaseCommand):
     """Show downloads statistic for package from PyPI.org.
     """
-
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_api(parser)
