@@ -22,9 +22,8 @@ from .base import BaseCommand
 class ProjectTestCommand(BaseCommand):
     """Test project build in temporary venvs.
     """
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_from(parser)
         builders.build_venv(parser)
