@@ -9,12 +9,9 @@ from pathlib import Path
 from dephell_venvs import VEnvs
 
 # app
-from ..actions import get_python, get_resolver, read_dotenv
+from ..actions import get_python, install_dep, read_dotenv
 from ..config import builders
 from ..context_tools import override_env_vars
-from ..controllers import analyze_conflict
-from ..models import Requirement
-from ..package_manager import PackageManager
 from .base import BaseCommand
 
 
@@ -62,7 +59,12 @@ class VenvRunCommand(BaseCommand):
             self.logger.warning('executable is not found in venv, trying to install...', extra=dict(
                 executable=command[0],
             ))
-            result = self._install(name=command[0], python_path=venv.python_path)
+            result = install_dep(
+                name=command[0],
+                python_path=venv.python_path,
+                logger=self.logger,
+                silent=self.config['silent'],
+            )
             if not result:
                 return False
         if not executable.exists():
@@ -88,26 +90,3 @@ class VenvRunCommand(BaseCommand):
 
         self.logger.info('command successfully completed')
         return True
-
-    def _install(self, name: str, python_path: Path) -> bool:
-        # resolve
-        resolver = get_resolver(reqs=[name])
-        self.logger.info('build dependencies graph...')
-        resolved = resolver.resolve(silent=self.config['silent'])
-        if not resolved:
-            conflict = analyze_conflict(resolver=resolver)
-            self.logger.warning('conflict was found')
-            print(conflict)
-            return False
-
-        # install
-        reqs = Requirement.from_graph(graph=resolver.graph, lock=True)
-        self.logger.info('installation...', extra=dict(
-            executable=python_path,
-            packages=len(reqs),
-        ))
-        code = PackageManager(executable=python_path).install(reqs=reqs)
-        if code != 0:
-            return False
-        self.logger.info('installed')
-        return True
