@@ -7,7 +7,7 @@ import attr
 from requests.auth import HTTPBasicAuth
 
 
-@attr.s(cmp=True, frozen=True)
+@attr.s(eq=True, order=True, frozen=True)
 class Auth(HTTPBasicAuth):
     hostname = attr.ib(type=str)
     username = attr.ib(type=str)
