@@ -19,6 +19,7 @@ from jinja2 import Environment
 from ...cache import JSONCache
 from ...cached_property import cached_property
 from ...config import config
+from ...constants import HOMEPAGE_FIELD
 from ...models.release import Release
 from ...models.simple_dependency import SimpleDependency
 from ...networking import aiohttp_session, requests_session
@@ -43,7 +44,7 @@ HISTORY_URL = 'https://api.github.com/repos/{repo}/commits?path={path}&per_page=
 CONTENT_URL = 'https://raw.githubusercontent.com/{repo}/{rev}/{path}'
 
 URL_FIELDS = {
-    'home': 'homepage',
+    'home': HOMEPAGE_FIELD,
     'dev_url': 'repository',
     'doc_url': 'documentation',
     'license_url': 'license',
