@@ -1,12 +1,10 @@
 # built-in
 import re
 
-# external
-import requests
-
 # app
-from ...config import config
 from ...cached_property import cached_property
+from ...config import config
+from ...networking import requests_session
 from .base import BaseRepo
 
 
@@ -30,7 +28,8 @@ class BitbucketRepo(BaseRepo):
             author=self.author,
             name=self.name,
         )
-        response = requests.get(url)
+        with requests_session() as session:
+            response = session.get(url)
 
         tags = []
         for tag in response.json()['values']:
